<?php

/**
 * Nav Menu package for Concrete5
 * Copyright 2020, Alex Borisov. All Rights Reserved.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @author Alex Borisov <linuxoidoz@gmail.com>
 * @copyright 2018-2020, Alex Borisov. All Rights Reserved.
 * @package Concrete\Package\ab_nav_menu
 */

namespace Concrete\Package\AbNavMenu\Block\AbNavMenu;

use Concrete\Core\Block\BlockController;
use Concrete\Core\Page\PageList;
use Concrete\Core\Page\Page;

class Controller extends BlockController
{
    
    protected $btWrapperClass = 'ccm-ui';
    protected $btInterfaceWidth = "600";
    protected $btInterfaceHeight = "600";
    protected $btTable = 'btAbNavMenu';
    protected $btDefaultSet = 'navigation';
    
    public function getBlockTypeDescription() 
    {
        return t("Add Simple Nav Menu block");
    }

    public function getBlockTypeName() 
    {
        return t("Simple Nav Menu");
    }

    public function on_start()
    {
        $this->set('app', $this->app);
    }
    
    public function registerViewAssets($outputContent = '')
    {
        $this->requireAsset('javascript', 'jquery');
        $this->requireAsset('javascript', 'jquery/ui');
        $this->requireAsset('css', 'jquery/ui');
    }
    
    public function view()
    {
        $pages = new PageList();
        
        $pages->filterByParentID($this->parent_page_id);
        if (!$this->show_excluded_from_nav) {
            $pages->filterByAttribute('exclude_nav', false);
        }
        $pages->sortByDisplayOrder();
        
        $this->set('pages', $pages->getResults());
        $this->set('menu_style', $this->menu_style);
        
        $page = Page::getCurrentPage();
        if ($page && !$page->isError()) {
            $this->set('page_id', $page->getCollectionID());
        }
        
        if ($this->include_home) {
            $this->set('home', Page::getByID(1));
        }
    }
    
    public function add()
    {
        $styles = [t('Links'), t('Inline List'), t('Tabs'), t('Pills'), t('Stacked'), t('Sidebar')];
        $this->set('styles', $styles);
    }
    
    public function edit()
    {
        $styles = [t('Links'), t('Inline List'), t('Tabs'), t('Pills'), t('Stacked'), t('Sidebar')];
        $this->set('styles', $styles);
    }
    
    public function save($data)
    {
        $data['menu_style'] = isset($data['menu_style']) ? $data['menu_style'] : 0;
        $data['parent_page_id'] = isset($data['parent_page_id']) ? $data['parent_page_id'] : 0;
        $data['include_home'] = isset($data['include_home']) ? 1 : 0;
        $data['show_children'] = isset($data['show_children']) ? 1 : 0;
        $data['parent_no_go'] = isset($data['parent_no_go']) ? 1 : 0;
        $data['show_excluded_from_nav'] = isset($data['show_excluded_from_nav']) ? 1 : 0;
        parent::save($data);
    }
}
